@@ -162,14 +162,15 @@ class PummelTemplateTagTestCase(TestCase):
         self.assertEqual(response.strip(), (
             '<MODULE>'
             '<CONTAINER type="data">'
-            '<GALLERY>'
-            '<ITEM>'
-            '<IMAGE href="/some/image/" float="true" align="" mime-type="image/jpeg" />'
-            '<TEXT><p><color value="#E40BBA">Title</color><br />'
-            '<color value="#666666">Published</color>'
+            '<TEXT><p>'
+            'Title<br />'
+            '\n    Published'
             '</p></TEXT>'
-            '</ITEM>'
-            '</GALLERY>'
+            '</CONTAINER>'
+            '</MODULE>'
+            '<MODULE>'
+            '<CONTAINER type="image">'
+            '<IMAGE href="/some/image/" float="true" align="" mime-type="image/jpeg" />'
             '</CONTAINER>'
             '</MODULE>'
         ))
@@ -186,7 +187,7 @@ class PummelTemplateTagTestCase(TestCase):
             '<CONTAINER type="data">'
             '<GALLERY>'
             '<ITEM>'
-            '<IMAGE href="#" float="true" align="left" mime-type="image/jpeg" />'
+            '<IMAGE href="%23" float="true" align="left" mime-type="image/jpeg" />'
             '<TEXT><p>'
             '<LINK href="/link/">Title</LINK><br />'
             '<small>Published date</small><br />'
@@ -211,7 +212,7 @@ class PummelTemplateTagTestCase(TestCase):
             '<CONTAINER type="data">'
             '<TEXT>'
             '<LINK href="/live/">'
-            '<IMAGE href="#" align="full" type="image/jpeg"/>'
+            '<IMAGE href="%23" align="full" type="image/jpeg"/>'
             '<TEXT><p><LINK href="/live/">This</LINK> is a promo description\n'
             '</p></TEXT>'
             '</LINK>'
@@ -310,7 +311,6 @@ class PummelTemplateTagTestCase(TestCase):
         ))
 
 
-
 class PummeliMiddlewareTestCase(TestCase):
     def test_redirect_respects_ignore_paths(self):
         client = Client()
@@ -322,3 +322,18 @@ class PummeliMiddlewareTestCase(TestCase):
 
         response = client.get('/redirect/')
         self.assertEquals(response['Content-Type'], 'text/html; charset=utf-8')
+
+
+class RemoteUserMiddlewareTestCase(TestCase):
+    def test_remote_user_respects_ignore_paths(self):
+        client = Client(HTTP_X_UP_CALLING_LINE_ID='0123456789')
+        response = client.get('/')
+        self.assertTrue('Username is: 0123456789' in response.content)
+
+        client = Client(HTTP_X_UP_CALLING_LINE_ID='0123456789')
+        response = client.get('/admin/')
+        self.assertFalse('Username is: 0123456789' in response.content)
+
+        client = Client(HTTP_X_UP_CALLING_LINE_ID='0123456789')
+        response = client.get('/vlivebanner/')
+        self.assertFalse('Username is: 0123456789' in response.content)
